@@ -49,17 +49,20 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
     """
     Load labels and coordinates from a .xyz file
 
-    Positional arguments:
-        f_name (str) : File name
+    Parameters
+    ----------
+        f_name (str) :
+            File name
+        atomic_numbers (bool, optional) :
+            If true, will read xyz file with atomic numbers and convert
+            to labels
 
-    Keyword arguments:
-        atomic_numbers (bool) : If true, will read xyz file with atomic numbers
-                                and convert to labels
-
-    Returns:
-        _labels (list) : atomic labels
-        _coords (list) : list of 3 element lists containing xyz coordinates
-                         of each atom
+    Returns
+    -------
+        _labels (list) :
+            atomic labels
+        _coords (list) :
+            list of 3 element lists containing xyz coordinates of each atom
     """
 
     if atomic_numbers:
@@ -82,21 +85,26 @@ def save_xyz(f_name: str, labels: list, coords: list,
     """
     Add numbers to a list of atomic labels
 
-    Positional arguments:
-        f_name (str) : File name
-        labels (list) : atomic labels
-        coords (list) : list of 3 element lists containing xyz coordinates of
-                        each atom
+    Parameters
+    ----------
+        f_name (str) :
+            File name
+        labels (list) :
+            atomic labels
+        coords (list) :
+            list of 3 element lists containing xyz coordinates of each atom
+        with_numbers (bool, optional) :
+            If True, add/overwrite numbers to labels before printing
+        verbose (bool, optional) :
+            Print information on filename to screen
+        mask (list, optional) :
+            n_atom list of 0 (exclude) and 1 (include) indicating which
+            atoms to print
+        atomic_numbers (bool, optional) :
+            If true, will save xyz file with atomic numbers
 
-    Keyword arguments:
-        with_numbers (bool)   : If True, add/overwrite numbers to labels before
-                                printing
-        verbose (bool)        : Print information on filename to screen
-        mask (list)           : n_atom list of 0 (exclude) and 1 (include)
-                                indicating which atoms to print
-        atomic_numbers (bool) : If true, will save xyz file with atomic numbers
-
-    Returns:
+    Returns
+    -------
         None
     """
 
@@ -141,14 +149,15 @@ def remove_numbers(labels: list):
     """
     Remove numbers from a list of atomic labels
 
-    Positional arguments:
-        labels (list) : atomic labels
+    Parameters
+    ----------
+        labels (list) :
+            atomic labels
 
-    Keyword arguments:
-        None
-
-    Returns:
-        labels_nn (list) : atomic labels without numbers
+    Returns
+    -------
+        labels_nn (list) :
+            atomic labels without numbers
     """
 
     labels_nn = []
@@ -167,16 +176,19 @@ def add_numbers(labels: list, style: str = 'per_element'):
     """
     Add numbers to a list of atomic labels
 
-    Positional arguments:
-        labels (list) : atomic labels
+    Parameters
+    ----------
+        labels (list) :
+            atomic labels
+        style (str, optional) :
+            {'per_element', 'sequential'}
+                'per_element' : Number by element e.g. Dy1, Dy2, N1, N2, etc.
+                'sequential' : Number the atoms 1->N regardless of element
 
-    Keyword arguments:
-        style (str) : {'per_element', 'sequential'}
-            'per_element' : Number by element e.g. Dy1, Dy2, N1, N2, etc.
-            'sequential' : Number the atoms 1->N regardless of element
-
-    Returns:
-        labels_wn (list) : atomic labels with numbers
+    Returns
+    -------
+        labels_wn (list) :
+            atomic labels with numbers
     """
 
     # remove numbers just in case
@@ -208,14 +220,15 @@ def count_n_atoms(form_str: str):
     """
     Count number of atoms in a chemical formula
 
-    Positional arguments:
-        form_str (str) : chemical formula string
+    Parameters
+    ----------
+        form_str (str) :
+            chemical formula string
 
-    Keyword arguments:
-        None
-
-    Returns:
-        n_atoms (int) : number of atoms in chemical formula
+    Returns
+    -------
+        n_atoms (int) :
+            number of atoms in chemical formula
     """
 
     form_dict = formstr_to_formdict(form_str)
@@ -230,14 +243,17 @@ def index_elements(labels: list, shift: int = 0):
     Return dictionary of element (keys) and indices (values) from list
     of labels
 
-    Positional arguments:
-        labels (list) : atomic labels
+    Parameters
+    ----------
+        labels (list) :
+            atomic labels
+        shift (int, optional):
+            additive shift to apply to all indices
 
-    Keyword arguments:
-        shift (int)   : additive shift to apply to all indices
-
-    Returns:
-        ele_index (dict) : dictionary of element (keys) and indices (values)
+    Returns
+    -------
+        ele_index (dict) :
+            dictionary of element (keys) and indices (values)
     """
 
     labels_nn = remove_numbers(labels)
@@ -257,14 +273,14 @@ def count_elements(labels: list):
     """
     Count number of each element in a list of elements
 
-    Positional arguments:
-        labels (list) : atomic labels
-
-    Keyword arguments:
-        None
-
-    Returns:
-        ele_count (dict) : dictionary of elements (keys) and counts (vals)
+    Parameters
+    ----------
+        labels (list) :
+            atomic labels
+    Returns
+    -------
+        ele_count (dict) :
+            dictionary of elements (keys) and counts (vals)
     """
 
     labels_nn = remove_numbers(labels)
@@ -284,14 +300,15 @@ def formstr_to_formdict(form_str: str):
     """
     Converts formula string into dictionary of {atomic label:quantity} pairs
 
-    Positional arguments:
-        form_string (str) : Chemical formula as string
+    Parameters
+    ----------
+        form_string (str) :
+            Chemical formula as string
 
-    Keyword arguments:
-        None
-
-    Returns:
-        form_dict (dict) : dictionary of {atomic label:quantity} pairs
+    Returns
+    -------
+        form_dict (dict) :
+            dictionary of {atomic label:quantity} pairs
     """
 
     form_dict = {}
@@ -310,14 +327,17 @@ def formdict_to_formstr(form_dict: dict, include_one: bool = False):
     Converts dictionary of {atomic label:quantity} pairs into
     a single formula string
 
-    Positional arguments:
-        form_dict (dict) : dictionary of {atomic label:quantity} pairs
+    Parameters
+    ----------
+        form_dict (dict) :
+            dictionary of {atomic label:quantity} pairs
+        include_one (bool, optional) :
+            Include 1 in final chemical formula e.g. C1H4
 
-    Keyword arguments:
-        include_one (bool) : Include 1 in final chemical formula e.g. C1H4
-
-    Returns:
-        form_string (str) : Chemical formula as string
+    Returns
+    -------
+        form_string (str) :
+            Chemical formula as string
     """
 
     # Formula labels and quantities as separate lists with same order
@@ -351,16 +371,17 @@ def formdict_to_formstr(form_dict: dict, include_one: bool = False):
 
 def contains_metal(form_string: str):
     """
-    Returns 1 if metal found in form_string else returns a 0
+    Indicates if a metal is found in a chemical formula string
 
-    Positional arguments:
-        form_string (str) : Chemical formula as string
+    Parameters
+    ----------
+        form_string (str) :
+            Chemical formula as string
 
-    Keyword arguments:
-        None
-
-    Returns:
-        metal_found (int) : Combined atomic labels
+    Returns
+    -------
+        metal_found (int) :
+            Combined atomic labels
     """
     metal_found = 0
 
@@ -377,18 +398,23 @@ def combine_xyz(labels_1: list, labels_2: list,
     """
     Combine two sets of labels and coordinates
 
-    Positional arguments:
-        labels_1 (list) : Atomic labels
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-        labels_2 (list) : Atomic labels
-        coords_2 (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels_1 (list) :
+            Atomic labels
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom
+        labels_2 (list) :
+            Atomic labels
+        coords_2 (list) :
+            list of lists of xyz coordinates of each atom
 
-    Keyword arguments:
-        None
-
-    Returns:
-        labels (list) : Combined atomic labels
-        coords (list) : Combined list of lists of xyz coordinates of each atom
+    Returns
+    -------
+        labels (list) :
+            Combined atomic labels
+        coords (list) :
+            Combined list of lists of xyz coordinates of each atom
     """
 
     # Concatenate labels lists
@@ -404,16 +430,19 @@ def get_neighborlist(labels: list, coords: list, adjust_cutoff: dict = {}):
     """
     Calculate ASE neighbourlist with cutoffs
 
-    Positional arguments:
-        labels (list) : Atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
+        adjust_cutoff (dict, optional) :
+            dictionary of atoms (keys) and new cutoffs (values)
 
-    Keyword arguments:
-        adjust_cutoff (dict) : dictionary of atoms (keys)
-                               and new cutoffs (values)
-
-    Returns:
-        neigh_list (ASE neighbourlist object) : Neighbourlist for system
+    Returns
+    -------
+        neigh_list (ASE neighbourlist object) :
+            Neighbourlist for system
     """
 
     # Remove labels if present
@@ -448,17 +477,19 @@ def get_adjacency(labels: list, coords: list, adjust_cutoff: dict = {},
     Calculate adjacency matrix using ASE built in cutoffs with option to
     modify them
 
-    Positional arguments:
-        labels (list) : Atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
+        adjust_cutoff (dict, optional) :
+            dictionary of atoms (keys) and new cutoffs (values)
 
-    Keyword arguments:
-        adjust_cutoff (dict) : dictionary of atoms (keys)
-                               and new cutoffs (values)
-
-    Returns:
-        adjacency (numpy array) : Adjacency matrix with same order
-                                  as labels/coords
+    Returns
+    -------
+        adjacency (numpy array) :
+            Adjacency matrix with same order as labels/coords
     """
 
     # Remove labels if present
@@ -487,21 +518,31 @@ def get_bonds(labels: list, coords: list, neigh_list=None,
     Using ASE. Only unique angles are saved.
     e.g. 0-1 and not 1-0
 
-    Positional arguments:
-        labels (list) : Atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
 
     Keyword arguments:
-        neigh_list (ASE neighbourlist object) : neighbourlist of system
-        f_name (str)  : filename to save bond list to
-        save (bool)   : Save bond list to file
-        verbose (bool): Print number of bonds to screen
-        style (str)   : {'index','label'}
-            indices : Bond list contains atom number
-            labels  : Bond list contains atom label
+        neigh_list (ASE neighbourlist object, optional) :
+            neighbourlist of system
+        f_name (str, optional) :
+            filename to save bond list to
+        save (bool, optional) :
+            Save bond list to file
+        verbose (bool, optional :
+            Print number of bonds to screen
+        style (str, optional :
+            {'index','label'}
+                indices : Bond list contains atom number
+                labels  : Bond list contains atom label
 
-    Returns:
-        bonds (list) : list of unique bonds (atom pairs)
+    Returns
+    -------
+        bonds (list) :
+            list of unique bonds (atom pairs)
     """
 
     # Remove labels if present
@@ -565,21 +606,29 @@ def get_angles(labels: list, coords: list, neigh_list=None,
     Using ASE. Only unique angles are saved.
     e.g. 0-1-2 but not 2-1-0
 
-    Positional arguments:
-        labels (list) : Atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
+        neigh_list (ASE neighbourlist object, optional) :
+            neighbourlist of system
+        f_name (str, optional) :
+            filename to save angle list to
+        save (bool, optional) :
+            Save angle list to file
+        verbose (bool, optional) :
+            Print number of angles to screen
+        style (str, optional) :
+            {'index','label'}
+                indices : Angle list contains atom number
+                labels  : Angle list contains atom label
 
-    Keyword arguments:
-        neigh_list (ASE neighbourlist object) : neighbourlist of system
-        f_name (str)  : filename to save angle list to
-        save (bool)   : Save angle list to file
-        verbose (bool): Print number of bonds to screen
-        style (str)   : {'index','label'}
-            indices : Bond list contains atom number
-            labels  : Bond list contains atom label
-
-    Returns:
-        angles (list) : list of unique angles (atom trios)
+    Returns
+    -------
+        angles (list) :
+            list of unique angles (atom trios)
     """
 
     # Remove labels if present
@@ -595,7 +644,7 @@ def get_angles(labels: list, coords: list, neigh_list=None,
     # Get object containing analysis of molecular structure
     ana = Analysis(mol, nl=neigh_list)
 
-    # Get bonds from ASE
+    # Get angles from ASE
     # Returns: list of lists of lists containing UNIQUE angles
     # Defined as
     # Atom 1 : [[atom,atom], [atom,atom]], ...
@@ -644,21 +693,29 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
     Using ASE. Only unique angles are saved.
     e.g. 0-1-2-3 but not 3-2-1-0
 
-    Positional arguments:
-        labels (list) : Atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
+        neigh_list (ASE neighbourlist object, optional) :
+            neighbourlist of system
+        f_name (str, optional) :
+            filename to save angle list to
+        save (bool, optional) :
+            Save angle list to file
+        verbose (bool, optional) :
+            Print number of dihedrals to screen
+        style (str, optional) :
+            {'index','label'}
+                indices : Dihedral list contains atom number
+                labels  : Dihedral list contains atom label
 
-    Keyword arguments:
-        neigh_list (ASE neighbourlist object) : neighbourlist of system
-        f_name (str)  : filename to save dihedral list to
-        save (bool)   : Save dihedral list to file
-        verbose (bool): Print number of bonds to screen
-        style (str)   : {'index','label'}
-            indices : Bond list contains atom number
-            labels  : Bond list contains atom label
-
-    Returns:
-        dihedrals (list) : list of unique dihedrals (atom quads)
+    Returns
+    -------
+        dihedrals (list) :
+            list of unique dihedrals (atom quads)
     """
 
     # Remove labels if present
@@ -674,7 +731,7 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
     # Get object containing analysis of molecular structure
     ana = Analysis(mol, nl=neigh_list)
 
-    # Get bonds from ASE
+    # Get dihedrals from ASE
     # Returns: list of lists of lists containing UNIQUE dihedrals
     # Defined as
     # Atom 1 : [[atom,atom,atom], [atom,atom,atom]], ...
@@ -726,14 +783,15 @@ def lab_to_num(labels: list):
     '''
     Convert atomic label to atomic number
 
-    Positional arguments:
-        labels (list) : Atomic labels
+    Parameters
+    ----------
+        labels (list) :
+            Atomic labels
 
-    Keyword arguments:
-        None
-
-    Returns:
-        numbers (list) : Atomic numbers
+    Returns
+    -------
+        numbers (list) :
+            Atomic numbers
     '''
 
     labels_nn = remove_numbers(labels)
@@ -747,14 +805,17 @@ def num_to_lab(numbers: list, numbered: bool = True):
     '''
     Convert atomic number to atomic labels
 
-    Positional arguments:
-        numbers (list) : Atomic numbers
+    Parameters
+    ----------
+        numbers (list) :
+            Atomic numbers
+        numbered (bool, optional) :
+            Add indexing number to end of atomic labels
 
-    Keyword arguments:
-        numbered (bool) : Add indexing number to end of atomic labels
-
-    Returns:
-        labels (list) : Atomic labels
+    Returns
+    -------
+        labels (list) :
+            Atomic labels
     '''
 
     labels = [atom_num_lab[num] for num in numbers]
@@ -771,14 +832,15 @@ def reflect_coords(coords: list):
     """
     Reflect coordinates through xy plane
 
-    Positional arguments:
-        coords (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        coords (list) :
+            list of lists of xyz coordinates of each atom
 
-    Keyword arguments:
-        None
-
-    Returns:
-        coords (list) : list of lists of xyz coordinates of each atom
+    Returns
+    -------
+        coords (list) :
+            list of lists of xyz coordinates of each atom
 
     """
 
@@ -818,48 +880,47 @@ def remove_broken(labels: list, coords: list, formulae: list,
     Uses ASE to generate adjacency matrix and draw out bonding in coords
     allowing formulae of fragments to be found.
 
+
+    Parameters
+    ----------
+        labels (list) :
+            list of atomic labels
+        coords (list) :
+            list of lists of xyz coordinates of each atom
+        formulae (list) :
+            list of chemical formulae stored as dictionaries with atomic
+            symbol (key) count (val) pairs
+        adjust_cutoff (dict, optional) :
+            dictionary of atoms (keys) and new cutoffs (values)
+        verbose (bool, optional) :
+            print molecule count to screen
+        save (bool, optional) :
+            Save molecules and incomplete fragments to separate xyz files
+        frag_f_name (str, optional) :
+            Name for xyz file containing fragmented structures
+        clean_f_name (str, optional) :
+            Name for xyz file containing full molecules
+        mask (list, optional) :
+            list of 0 (exclude) and 1 (include) for each element
+                - if used, final lists will exclude masked elements
+        skip (list, optional) :
+            List of atomic indices which shall not be visited when tracing
+            bonding network
     Returns
-        - labels and coordinates of molecules
-            ordered such that molecules are grouped together and
-            metal containing molecules are at the top of the coords array
-        - labels and coordinates of fragments
-        - dictionary containing indices of complete molecules, where
-          the indices correspond to the original ordering of labels and
-          coords given to this function
-
-    Positional arguments:
-        labels (list) : list of atomic labels
-        coords (list) : list of lists of xyz coordinates of each atom
-        formulae (list) : list of chemical formulae stored as dictionaries
-                          with atomic symbol (key) count (val) pairs
-
-    Keyword arguments:
-        adjust_cutoff (dict)  : dictionary of atoms (keys) and
-                                new cutoffs (values)
-        verbose (bool)        : print molecule count to screen
-        save (bool)           : Save molecules and incomplete fragments to
-                                separate xyz files
-        frag_f_name (str)     : Name for xyz file containing fragmented
-                                structures
-        clean_f_name (str)    : Name for xyz file containing full molecules
-        mask (list)           : list of 0 (exclude) and 1 (include) for each
-                                element
-                                - if used, final lists will exclude masked
-                                  elements
-        skip (list)           : List of atomic indices which shall not be
-                                visited when tracing bonding network
-    Returns:
-        labels_clean (list)  : list of atomic labels for full molecules
-        coords_clean (list)  : list of lists of xyz coordinates of each atom
-                               for full molecules
-        labels_fragments (list) : list of atomic labels for fragments
-        coords_fragments (list) : list of lists of xyz coordinates of each
-                                  atom for fragments
-        mol_indices     (dict) : dictionary containing indices of complete
-                                 molecules -
-                                    keys = molecular formula,
-                                    vals = list of lists of atomic indices
-                                           for each atom
+    -------
+        labels_clean (list) :
+            list of atomic labels for full molecules
+        coords_clean (list)  :
+            list of lists of xyz coordinates of each atom for full molecules
+        labels_fragments (list) :
+            list of atomic labels for fragments
+        coords_fragments (list) :
+            list of lists of xyz coordinates of each atom for fragments
+        mol_indices     (dict) :
+            dictionary containing indices of complete molecules -
+                keys = molecular formula,
+                vals = list of lists of atomic indices
+                        for each atom
     """
 
     # Remove label numbers if present
@@ -1032,15 +1093,19 @@ def _mask_list(_list: list, mask: list, opp_mask: bool = False):
     """
     Truncates list to only include elements specified by 1 in mask
 
-    Positional arguments:
-        _list (list) : list to mask
-        mask (list) : list of 0 (exclude) and 1 (include) for each element
+    Parameters
+    ----------
+        _list (list) :
+            list to mask
+        mask (list) :
+            list of 0 (exclude) and 1 (include) for each element
 
-    Keyword arguments:
-        opp_mask (bool) : Apply mask in opposite fashion:
-                            0 (include) and 1 (exclude)
+        opp_mask (bool, optional) :
+            Apply mask in opposite fashion:
+                0 (include) and 1 (exclude)
 
-    Returns:
+    Returns
+    -------
         _list_masked (float) : Masked list
     """
 
@@ -1060,15 +1125,17 @@ def _reorder_list(_list: list, order: list):
     """
     Reorders list using indices in order
 
-    Positional arguments:
-        _list (list) : list to reorder
-        order (list) : New order for list
+    Parameters
+    ----------
+        _list (list) :
+            list to reorder
+        order (list) :
+            New order for list
 
-    Keyword arguments:
-        None
-
-    Returns:
-        _list_reordered (float) : Reordered list
+    Returns
+    -------
+        _list_reordered (float) :
+            Reordered list
     """
 
     # Apply mask to list
@@ -1083,16 +1150,17 @@ def _calculate_rmsd(coords_1: list, coords_2: list):
     RMSD = sqrt(mean(deviations**2))
     Where deviations are defined as norm([x1,y1,z1]-[x2,y2,z2])
 
-    Positional arguments:
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-        coords_2 (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom
+        coords_2 (list) :
+            list of lists of xyz coordinates of each atom
 
-    Keyword arguments:
-        None
-
-    Returns:
-        rmsd (float) : Root mean square of norms of deviation
-                       between two structures
+    Returns
+    -------
+        rmsd (float) :
+            Root mean square of norms of deviation between two structures
     """
 
     # Check there are the same number of coordinates
@@ -1124,23 +1192,26 @@ def calculate_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
     coords_1 and coords_2 can also be reordered if new orders are specified
         - note this occurs BEFORE masking
 
-    Positional arguments:
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-        coords_2 (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom
+        coords_2 (list) :
+            list of lists of xyz coordinates of each atom
 
-    Keyword arguments:
-        mask_1 (list)  : list of 0 (exclude) and 1 (include) for each
-                            element in coords_1
-        mask_2 (list)  : list of 0 (exclude) and 1 (include) for each
-                            element in coords_2
-        order_1 (list) : list of new indices for coords_1
-                            - applied BEFORE masking
-        order_2 (list) : list of new indices for coords_2
-                            - applied BEFORE masking
+        mask_1 (list) :
+            list of 0 (exclude) and 1 (include) for each element in coords_1
+        mask_2 (list) :
+            list of 0 (exclude) and 1 (include) for each element in coords_2
+        order_1 (list) :
+            list of new indices for coords_1 - applied BEFORE masking
+        order_2 (list) :
+            list of new indices for coords_2 - applied BEFORE masking
 
-    Returns:
-        rmsd (float) : Root mean square of norms of deviation between
-                        two structures
+    Returns
+    -------
+        rmsd (float) :
+            Root mean square of norms of deviation between two structures
     """
 
     # Set up new ordering
@@ -1185,18 +1256,21 @@ def rotate_coords(coords: list, alpha: float, beta: float, gamma: float):
     Rotates coordinates by alpha, beta, gamma using the zyz convention
     https://easyspin.org/easyspin/documentation/eulerangles.html
 
-    Positional arguments:
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-        alpha (float) : alpha angle in radians
-        beta (float)  : beta  angle in radians
-        gamma (float) : gamma angle in radians
+    Parameters
+    ----------
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom
+        alpha (float) :
+            alpha angle in radians
+        beta (float)  :
+            beta  angle in radians
+        gamma (float) :
+            gamma angle in radians
 
-    Keyword arguments:
-        None
-
-    Returns:
-        rot_coords (list) : list of lists of xyz coordinates of each
-                            atom after rotation
+    Returns
+    -------
+        rot_coords (list) :
+            list of lists of xyz coordinates of each atom after rotation
     """
 
     R = np.zeros([3, 3])
@@ -1236,23 +1310,26 @@ def minimise_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
     coords_1 and coords_2 can also be reordered if new orders are specified
         - note this occurs BEFORE masking
 
-    Positional arguments:
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-        coords_2 (list) : list of lists of xyz coordinates of each atom
+    Parameters
+    ----------
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom
+        coords_2 (list) :
+            list of lists of xyz coordinates of each atom
 
-    Keyword arguments:
-        mask_1 (list)  : list of 0 (exclude) and 1 (include) for each
-                            element in coords_1
-        mask_2 (list)  : list of 0 (exclude) and 1 (include) for each
-                            element in coords_2
-        order_1 (list) : list of new indices for coords_1
-                            - applied BEFORE masking
-        order_2 (list) : list of new indices for coords_2
-                            - applied BEFORE masking
+        mask_1 (list)  :
+            list of 0 (exclude) and 1 (include) for each element in coords_1
+        mask_2 (list)  :
+            list of 0 (exclude) and 1 (include) for each element in coords_2
+        order_1 (list) :
+            list of new indices for coords_1 - applied BEFORE masking
+        order_2 (list) :
+            list of new indices for coords_2 - applied BEFORE masking
 
-    Returns:
-        rmsd (float) : Root mean square of norms of deviation between
-                        two structures
+    Returns
+    -------
+        rmsd (float) :
+            Root mean square of norms of deviation between two structures
     """
 
     # Set up new ordering
@@ -1303,19 +1380,19 @@ def _rotate_and_rmsd(angs: list, coords_1: list, coords_2: list):
     https://easyspin.org/easyspin/documentation/eulerangles.html
     then calcualtes the rmsd between coords_1 and coords_2
 
-    Positional arguments:
-        coords_1 (list) : list of lists of xyz coordinates of each atom
-                            of first system
-        coords_2 (list) : list of lists of xyz coordinates of each atom
-                            of second system
-        angs (list)     : alpha, beta, gamma in radians
+    Parameters
+    ----------
+        coords_1 (list) :
+            list of lists of xyz coordinates of each atom of first system
+        coords_2 (list) :
+            list of lists of xyz coordinates of each atom of second system
+        angs (list) :
+            alpha, beta, gamma in radians
 
-    Keyword arguments:
-        None
-
-    Returns:
-        rot_coords (list) : list of lists of xyz coordinates of each atom
-                                after rotation
+    Returns
+    -------
+        rot_coords (list) :
+            list of lists of xyz coordinates of each atom after rotation
     """
 
     # Rotate coordinates of first system
